@@ -5,17 +5,17 @@ use warnings;
 package Hash::Ordered;
 # ABSTRACT: A fast, pure-Perl ordered hash class
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 use Carp ();
 
 use constant {
-    _DATA => 0,         # unordered data
-    _KEYS => 1,         # ordered keys
-    _INDX => 2,         # index into _KEYS (on demand)
-    _OFFS => 3,         # index offset for optimized shift/unshift
-    _GCNT => 4,         # garbage count
-    _ITER => 5,         # for tied hash support
+    _DATA => 0, # unordered data
+    _KEYS => 1, # ordered keys
+    _INDX => 2, # index into _KEYS (on demand)
+    _OFFS => 3, # index offset for optimized shift/unshift
+    _GCNT => 4, # garbage count
+    _ITER => 5, # for tied hash support
 };
 
 use constant {
@@ -401,8 +401,9 @@ sub merge {
 
 sub as_list {
     my ( $self, @keys ) = @_;
-    @keys = grep !ref($_), @{ $self->[_KEYS] } unless @keys;
-    return map { ; $_ => $self->[_DATA]{$_} } @keys;
+    return
+      map { ; $_ => $self->[_DATA]{$_} }
+      ( @keys ? @keys : grep !ref($_), @{ $self->[_KEYS] } );
 }
 
 #pod =method iterator
@@ -653,7 +654,7 @@ Hash::Ordered - A fast, pure-Perl ordered hash class
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
